Crate spin_macro

Crate spin_macro 

Macros

dependencies
This macro generates code from a Spin components dependencies using wit-bindgen. During expansion the macro will check for existence of a spin-dependencies.wit in the developers project directory and if it is present (used to indicate the presence of dependencies in the manifest) will invoke wit-bindgen to generate the bindings.

Attribute Macros

http_service
Marks an async fn as an HTTP component entrypoint for Spin.
redis_subscriber
The entrypoint to a Spin Redis component.