This macro generates code from a Spin components dependencies using wit-bindgen. During expansion the
macro will check for existence of a spin-dependencies.wit in the developers project directory
and if it is present (used to indicate the presence of dependencies in the manifest) will invoke
wit-bindgen to generate the bindings.